export class StyleSheet {
}
StyleSheet.createThemedStyles = (styles, theme) => {
    return Object.keys(styles).reduce((acc, key) => {
        return { ...acc, [key]: StyleSheet.createThemedStyle(styles[key], theme) };
    }, {});
};
StyleSheet.createThemedStyle = (style, theme) => {
    return Object.keys(style).reduce((acc, key) => {
        const value = style[key];
        return { ...acc, [key]: StyleSheet.getThemeValue(value, theme, value) };
    }, {});
};
StyleSheet.createCompiledTheme = (theme) => {
    return Object.keys(theme).reduce((acc, key) => {
        return { ...acc, [key]: StyleSheet.getThemeValue(key, theme, key) };
    }, {});
};
StyleSheet.getThemeValue = (name, theme, fallback) => {
    if (StyleSheet.isReference(name)) {
        const themeKey = StyleSheet.toThemeKey(name);
        return StyleSheet.findThemeValue(themeKey, theme) || fallback;
    }
    return StyleSheet.findThemeValue(name, theme) || fallback;
};
StyleSheet.findThemeValue = (name, theme) => {
    const value = theme[name];
    if (StyleSheet.isReference(value)) {
        const themeKey = StyleSheet.toThemeKey(value);
        return StyleSheet.findThemeValue(themeKey, theme);
    }
    return value;
};
/**
 * @returns true if theme value references to another
 */
StyleSheet.isReference = (value) => {
    return `${value}`.startsWith('$');
};
/**
 * Transforms reference key to theme key
 */
StyleSheet.toThemeKey = (value) => {
    return `${value}`.substring(1);
};
//# sourceMappingURL=styleSheet.service.js.map