import { I18nManager, } from 'react-native';
import { I18nLayoutFlexMap } from './i18nLayoutFlexMap';
class NativeI18nLayoutService {
    isRTL() {
        return I18nManager.isRTL;
    }
    select(ltr, rtl) {
        return this.isRTL() ? rtl : ltr;
    }
    /**
     * Iterates through I18nLayoutFlexMap and reverses style values if needed.
     *
     * @param {ViewStyle} source - style to convert
     * @param {boolean} rtl - is layout currently in RTL mode (Needed for tests, because unable to mock this)
     *
     * @returns {ViewStyle} - style reversed to fit i18n
     */
    toI18nStyle(source, rtl = this.isRTL()) {
        const i18nStyle = Object.keys(I18nLayoutFlexMap).reduce((style, prop) => {
            const currentStyleValue = source[prop];
            if (currentStyleValue) {
                const i18nStyleValue = I18nLayoutFlexMap[prop].toI18n(currentStyleValue, rtl);
                return { ...style, [prop]: i18nStyleValue };
            }
            return style;
        }, {});
        return { ...source, ...i18nStyle };
    }
}
export const I18nLayoutService = new NativeI18nLayoutService();
//# sourceMappingURL=i18nLayout.service.js.map