/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { GestureResponderEvent, PanResponderCallbacks, PanResponderGestureState, StyleProp, TextStyle, TouchableOpacityProps, ViewProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
export interface ToggleProps extends StyledComponentProps, TouchableOpacityProps {
    checked?: boolean;
    disabled?: boolean;
    status?: string;
    size?: string;
    text?: string;
    textStyle?: StyleProp<TextStyle>;
    onChange?: (checked: boolean) => void;
}
export declare type ToggleElement = React.ReactElement<ToggleProps>;
/**
 * Styled `Toggle` component.
 *
 * @extends React.Component
 *
 * @property {boolean} checked - Determines whether component is checked.
 * Default is `false`.
 *
 * @property {boolean} disabled - Determines whether component is disabled.
 * Default is `false.
 *
 * @property {string} status - Determines the status of the component.
 * Can be `basic`, `primary`, `success`, `info`, `warning`, `danger` or `control`.
 * Default is `basic`.
 *
 * @property {string} text - Determines text of the component.
 *
 * @property {StyleProp<TextStyle>} textStyle - Customizes text style.
 *
 * @property {(checked: boolean) => void} onChange - Fires when selection state is changed.
 *
 * @property {TouchableOpacityProps} ...TouchableOpacityProps - Any props applied to TouchableOpacity component.
 *
 * @overview-example ToggleSimpleUsage
 *
 * @overview-example ToggleStates
 *
 * @overview-example ToggleStatus
 *
 * @example ToggleInlineStyling
 */
export declare class ToggleComponent extends React.Component<ToggleProps> implements PanResponderCallbacks {
    static styledComponentName: string;
    private panResponder;
    private thumbWidthAnimation;
    private thumbTranslateAnimation;
    private ellipseScaleAnimation;
    private thumbTranslateAnimationActive;
    private webEventResponder;
    constructor(props: ToggleProps);
    onMouseEnter: () => void;
    onMouseLeave: () => void;
    onFocus: () => void;
    onBlur: () => void;
    onStartShouldSetPanResponder: () => boolean;
    onStartShouldSetPanResponderCapture: () => boolean;
    onMoveShouldSetPanResponder: () => boolean;
    onMoveShouldSetPanResponderCapture: () => boolean;
    onPanResponderTerminationRequest: () => boolean;
    onPanResponderGrant: () => void;
    onPanResponderMove: () => boolean;
    onPanResponderRelease: (e: GestureResponderEvent, gestureState: PanResponderGestureState) => void;
    private onPressIn;
    private onPressOut;
    private onPress;
    private getComponentStyle;
    private animateThumbTranslate;
    private animateThumbWidth;
    private animateEllipseScale;
    private stopAnimations;
    private toggle;
    private renderTextElement;
    private renderComponentChildren;
    render(): React.ReactElement<ViewProps>;
}
export declare const Toggle: import("../../theme").StyledComponentClass<ToggleProps>;
