/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { StyleProp, TextStyle } from 'react-native';
import { StyledComponentProps, StyleType } from '../../theme';
import { IconElement } from '../icon/icon.component';
import { PopoverElement, PopoverProps } from '../popover/popover.component';
declare type IconProp = (style: StyleType) => IconElement;
declare type WrappingElement = React.ReactElement;
export interface TooltipProps extends StyledComponentProps, Omit<PopoverProps, 'content'> {
    text: string;
    textStyle?: StyleProp<TextStyle>;
    icon?: IconProp;
    children: WrappingElement;
}
export declare type TooltipElement = React.ReactElement<TooltipProps>;
/**
 * Tooltip displays informative text when users focus on or tap an element.
 *
 * @extends React.Component
 *
 * @property {boolean} visible - Determines whether popover is visible or not.
 *
 * @property {string} text - Determines the text of the tooltip
 *
 * @property {(style: StyleType) => ReactElement} icon - Determines icon of the component.
 *
 * @property {StyleProp<TextStyle>} textStyle - Customizes text style.
 *
 * @property {ReactElement} children - Determines the element "above" which popover will be shown.
 *
 * @property {string | PopoverPlacement} placement - Determines the actualPlacement of the popover.
 * Can be `left`, `top`, `right`, `bottom`, `left start`, `left end`, `top start`, `top end`, `right start`,
 * `right end`, `bottom start` or `bottom end`.
 * Default is `bottom`.
 * Tip: use one of predefined placements instead of strings, e.g `PopoverPlacements.TOP`
 *
 * @property {boolean} fullWidth - Determines whether content element should have same width as child element.
 *
 * @property {boolean} allowBackdrop - Determines whether user can tap on back-drop.
 * Default is `false`.
 *
 * @property {StyleProp<ViewStyle>} backdropStyle - Determines the style of backdrop.
 *
 * @property {() => void} onBackdropPress - Determines component's behavior when the user is
 * tapping on back-drop.
 *
 * @overview-example TooltipSimpleUsage
 *
 * @overview-example TooltipWithIcon
 *
 * @overview-example TooltipStyledBackdrop
 *
 * @overview-example TooltipPlacement
 *
 * @example TooltipWithExternalSourceIcon
 *
 * @example TooltipInlineStyling
 */
export declare class TooltipComponent extends React.Component<TooltipProps> {
    static styledComponentName: string;
    private getComponentStyle;
    private renderTextElement;
    private renderIconElement;
    private renderContentElementChildren;
    private renderPopoverIndicatorElement;
    private renderPopoverContentElement;
    render(): PopoverElement;
}
export declare const Tooltip: import("../../theme").StyledComponentClass<TooltipProps>;
export {};
